@@ -82,7 +82,6 @@ OC.L10N.register(
     "Phonetic last name" : "せい",
     "Display name" : "表示名",
     "Last modified" : "最終更新日",
-    "Sort by" : "ソート",
     "Manages" : "管理",
     "Oversees" : "統括",
     "An error happened during the config change" : "構成の変更中にエラーが発生しました",
@@ -310,7 +309,6 @@ OC.L10N.register(
     "General settings" : "一般設定",
     "(refreshed once per week)" : "(週に1回更新)",
     "{addressbookname} (Disabled)" : "{addressbookname} (無効)",
-    "Sort by {sorting}" : "{sorting} で整列",
     "Unique password …" : "固有パスワード...",
     "Search contacts …" : "連絡先を検索...",
     "Loading members list …" : "メンバーリストを読み込んでいます…",
