@@ -64,7 +64,6 @@ OC.L10N.register(
     "Phonetic last name" : "성 표음",
     "Display name" : "표시 이름",
     "Last modified" : "수정한 날짜",
-    "Sort by" : "다음으로 정렬",
     "An error happened during the config change" : "변경 사항을 설정하는 중 오류 발생",
     "Save" : "저장",
     "Change unique password" : "독자 암호 변경",
@@ -245,7 +244,6 @@ OC.L10N.register(
     "General settings" : "일반 설정",
     "(refreshed once per week)" : "(주 1회 새로고침)",
     "{addressbookname} (Disabled)" : "{addressbookname} (비활성화됨)",
-    "Sort by {sorting}" : "{sorting}(으)로 정렬",
     "Unique password …" : "독자 암호 ...",
     "Search contacts …" : "연락처 검색…",
     "Loading members list …" : "회원 목록 불러오는 중 ...",
