@@ -88,7 +88,6 @@ OC.L10N.register(
     "Phonetic last name" : "语音姓氏",
     "Display name" : "显示名称",
     "Last modified" : "上一次更改",
-    "Sort by" : "排序",
     "Manages" : "管理",
     "Oversees" : "监督",
     "An error happened during the config change" : "更改配置时发生一个错误",
@@ -341,7 +340,6 @@ OC.L10N.register(
     "General settings" : "一般设置",
     "(refreshed once per week)" : "（每周刷新）",
     "{addressbookname} (Disabled)" : "{addressbookname}（已禁用）",
-    "Sort by {sorting}" : "以 {sorting} 排序",
     "Unique password …" : "唯一密码…",
     "Search contacts …" : "搜索联系人…",
     "Invite members to team" : "邀请成员加入团队",
