@@ -25,8 +25,12 @@ OC.L10N.register(
     "Manage team" : "管理團隊",
     "Leave team" : "離開團隊",
     "Delete team" : "刪除團隊",
+    "Setting saved" : "已保存設定",
+    "Failed to save setting" : "無法保存設定",
     "Contacts settings" : " 通訊錄設定",
+    "General" : "一般",
     "Update avatars from social media" : "從社群媒體更新虛擬化身大頭照",
+    "Refreshed once per week" : "每星期重新整理一次",
     "Address books" : "通訊錄",
     "Rename" : "重新命名",
     "Export" : "導出",
@@ -78,6 +82,7 @@ OC.L10N.register(
     "Import from files" : "從檔案導入",
     "Importing is disabled because there are no address books available" : "已停用導入，因為沒有可用的通訊錄",
     "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
+    "New address book" : "新通訊錄",
     "Add new address book" : "添加新通訊錄",
     "Cancel" : "取消",
     "Add" : "添加",
@@ -87,7 +92,7 @@ OC.L10N.register(
     "Phonetic last name" : "音頻姓",
     "Display name" : "顯示名稱",
     "Last modified" : "上次修改",
-    "Sort by" : "排序",
+    "Sort contacts by" : "按以下方式對聯絡人進行排序",
     "Manages" : "管理",
     "Oversees" : "監督",
     "An error happened during the config change" : "配置更改期間發生錯誤",
@@ -100,14 +105,32 @@ OC.L10N.register(
     "Close" : "關閉",
     "There is no description for this team" : "此團隊沒有描述",
     "Enter a description for the team" : "輸入團隊的描述",
+    "Team folder" : "團隊資料夾",
+    "New Team folder" : "新團隊資料夾",
+    "Folder name" : "資料夾名字",
+    "Talk conversation" : "Talk 對話",
+    "New Talk conversation" : "新 Talk 對話",
     "Conversation name" : "對話名稱",
+    "Collective" : "知識庫",
     "Calendar" : "日曆",
+    "New calendar" : "新日曆",
+    "Calendar name" : "日曆名稱",
+    "Deck board" : "Deck 面板",
+    "New Deck board" : "新 Deck 面板",
+    "Board name" : "面板名稱",
+    "Deck app is not installed. Please install it to create team boards." : "未安裝 Deck 應用程式。請安裝以建立團隊面板。",
+    "Unknown resource type" : "不詳的資源類型",
+    "Team calendar \"{resourceName}\" created and shared with team" : "已建立團隊日曆「{resourceName}」並分享給團隊",
+    "{resourceType} \"{resourceName}\" created and shared with team" : "已建立 {resourceType}「{resourceName}」並分享給團隊",
+    "A calendar named \"{name}\" already exists. Please choose a different name." : "名為「{name}」的日曆已存在。請選擇其他名稱。",
+    "Failed to create {resourceType}: {error}" : "建立 {resourceType} 失敗：{error}",
     "An error happened while saving {fields}" : "儲存 {fields} 時發生了錯誤",
     "Team name" : "團隊名字",
     "Team owner" : "團隊所有者",
     "Edit" : "編輯",
     "Request to join" : "請求加入",
     "Create" : "新增",
+    "Show in Calendar" : "在日曆上顯示",
     "Your request to join this team is pending approval" : "您加入此團隊的請求正在等待批准",
     "You are not a member of {circle}" : "您不是 {circle} 的成員",
     "Members" : "成員",
@@ -341,7 +364,6 @@ OC.L10N.register(
     "General settings" : "一般設定",
     "(refreshed once per week)" : "（每週重新整理一次）",
     "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
-    "Sort by {sorting}" : "按 {sorting} 排序",
     "Unique password …" : "獨一無二的密碼 ...",
     "Search contacts …" : "搜尋聯絡人…",
     "Invite members to team" : "邀請成員加入團隊",
