@@ -21,12 +21,13 @@ class TumblrProvider implements ISocialProvider {
 	 *
 	 * @return bool
 	 */
+	#[\Override]
 	public function supportsContact(array $contact):bool {
 		if (!array_key_exists('X-SOCIALPROFILE', $contact)) {
 			return false;
 		}
 		$socialprofiles = $this->getProfileIds($contact);
-		return isset($socialprofiles) && count($socialprofiles) > 0;
+		return count($socialprofiles) > 0;
 	}
 
 	/**
@@ -36,6 +37,7 @@ class TumblrProvider implements ISocialProvider {
 	 *
 	 * @return array
 	 */
+	#[\Override]
 	public function getImageUrls(array $contact):array {
 		$profileIds = $this->getProfileIds($contact);
 		$urls = [];
